import { useState, useEffect } from 'react';

function useMediaQuery(queryInput) {
  var query = queryInput.replace(/^@media( ?)/m, '');
  var supportMatchMedia = typeof window !== 'undefined' && typeof window.matchMedia !== 'undefined';
  var defaultMatches = false;
  var matchMedia = supportMatchMedia ? window.matchMedia : null;

  var _useState = useState(function () {
    if (supportMatchMedia) return matchMedia(query).matches;
    return defaultMatches;
  }),
      match = _useState[0],
      setMatch = _useState[1];

  useEffect(function () {
    var active = true;
    if (!supportMatchMedia) return;
    var queryList = matchMedia(query);

    var updateMatch = function updateMatch() {
      if (active) setMatch(queryList.matches);
    };

    updateMatch();
    queryList.addListener(updateMatch);
    return function () {
      active = false;
      queryList.removeListener(updateMatch);
    };
  }, [query, matchMedia, supportMatchMedia]);
  return match;
}

export default useMediaQuery;